@@ -18,7 +18,9 @@
 #include "keylistview.h"
 #include "progressdialog.h"
 
+#include <libkleo/compliance.h>
 #include <libkleo/dn.h>
+#include <libkleo/formatting.h>
 
 #include <kleo_ui_debug.h>
 
@@ -32,7 +34,6 @@
 
 #include <QApplication>
 #include <QCheckBox>
-#include <QDateTime>
 #include <QDialogButtonBox>
 #include <QFrame>
 #include <QHBoxLayout>
@@ -53,6 +54,8 @@
 #include <iterator>
 #include <string.h>
 
+using namespace Kleo;
+
 static bool checkKeyUsage(const GpgME::Key &key, unsigned int keyUsage, QString *statusString = nullptr)
 {
     auto setStatusString = [statusString](const QString &status) {
@@ -61,7 +64,7 @@ static bool checkKeyUsage(const GpgME::Key &key, unsigned int keyUsage, QString
         }
     };
 
-    if (keyUsage & Kleo::KeySelectionDialog::ValidKeys) {
+    if (keyUsage & KeySelectionDialog::ValidKeys) {
         if (key.isInvalid()) {
             if (key.keyListMode() & GpgME::Validate) {
                 qCDebug(KLEO_UI_LOG) << "key is invalid";
@@ -86,40 +89,41 @@ static bool checkKeyUsage(const GpgME::Key &key, unsigned int keyUsage, QString
         }
     }
 
-    if (keyUsage & Kleo::KeySelectionDialog::EncryptionKeys && !key.canEncrypt()) {
+    if (keyUsage & KeySelectionDialog::EncryptionKeys && !key.canEncrypt()) {
         qCDebug(KLEO_UI_LOG) << "key can't encrypt";
         setStatusString(i18n("The key is not designated for encryption."));
         return false;
     }
-    if (keyUsage & Kleo::KeySelectionDialog::SigningKeys && !key.canSign()) {
+    if (keyUsage & KeySelectionDialog::SigningKeys && !key.canSign()) {
         qCDebug(KLEO_UI_LOG) << "key can't sign";
         setStatusString(i18n("The key is not designated for signing."));
         return false;
     }
-    if (keyUsage & Kleo::KeySelectionDialog::CertificationKeys && !key.canCertify()) {
+    if (keyUsage & KeySelectionDialog::CertificationKeys && !key.canCertify()) {
         qCDebug(KLEO_UI_LOG) << "key can't certify";
         setStatusString(i18n("The key is not designated for certifying."));
         return false;
     }
-    if (keyUsage & Kleo::KeySelectionDialog::AuthenticationKeys && !key.canAuthenticate()) {
+    if (keyUsage & KeySelectionDialog::AuthenticationKeys && !key.canAuthenticate()) {
         qCDebug(KLEO_UI_LOG) << "key can't authenticate";
         setStatusString(i18n("The key is not designated for authentication."));
         return false;
     }
 
-    if (keyUsage & Kleo::KeySelectionDialog::SecretKeys && !(keyUsage & Kleo::KeySelectionDialog::PublicKeys) && !key.hasSecret()) {
+    if (keyUsage & KeySelectionDialog::SecretKeys && !(keyUsage & KeySelectionDialog::PublicKeys) && !key.hasSecret()) {
         qCDebug(KLEO_UI_LOG) << "key isn't secret";
         setStatusString(i18n("The key is not secret."));
         return false;
     }
 
-    if (keyUsage & Kleo::KeySelectionDialog::TrustedKeys && key.protocol() == GpgME::OpenPGP &&
+    if (keyUsage & KeySelectionDialog::TrustedKeys && key.protocol() == GpgME::OpenPGP &&
         // only check this for secret keys for now.
         // Seems validity isn't checked for secret keylistings...
         !key.hasSecret()) {
         std::vector<GpgME::UserID> uids = key.userIDs();
         for (std::vector<GpgME::UserID>::const_iterator it = uids.begin(); it != uids.end(); ++it) {
             if (!it->isRevoked() && it->validity() >= GpgME::UserID::Marginal) {
+                setStatusString(i18n("The key can be used."));
                 return true;
             }
         }
@@ -144,15 +148,10 @@ static bool checkKeyUsage(const std::vector<GpgME::Key> &keys, unsigned int keyU
     return true;
 }
 
-static inline QString time_t2string(time_t t)
-{
-    return QDateTime::fromSecsSinceEpoch(t).toString();
-}
-
 namespace
 {
 
-class ColumnStrategy : public Kleo::KeyListView::ColumnStrategy
+class ColumnStrategy : public KeyListView::ColumnStrategy
 {
 public:
     ColumnStrategy(unsigned int keyUsage);
@@ -161,6 +160,7 @@ public:
     int width(int col, const QFontMetrics &fm) const override;
 
     QString text(const GpgME::Key &key, int col) const override;
+    QString accessibleText(const GpgME::Key &key, int column) const override;
     QString toolTip(const GpgME::Key &key, int col) const override;
     QIcon icon(const GpgME::Key &key, int col) const override;
 
@@ -175,7 +175,7 @@ static QString iconPath(const QString &name)
 }
 
 ColumnStrategy::ColumnStrategy(unsigned int keyUsage)
-    : Kleo::KeyListView::ColumnStrategy()
+    : KeyListView::ColumnStrategy()
     , mKeyGoodPix(iconPath(QStringLiteral("key_ok")))
     , mKeyBadPix(iconPath(QStringLiteral("key_bad")))
     , mKeyUnknownPix(iconPath(QStringLiteral("key_unknown")))
@@ -209,7 +209,7 @@ int ColumnStrategy::width(int col, const QFontMetrics &fm) const
         }
         return 8 * maxWidth + 2 * 16 /* KIconLoader::SizeSmall */;
     }
-    return Kleo::KeyListView::ColumnStrategy::width(col, fm);
+    return KeyListView::ColumnStrategy::width(col, fm);
 }
 
 QString ColumnStrategy::text(const GpgME::Key &key, int col) const
@@ -217,7 +217,7 @@ QString ColumnStrategy::text(const GpgME::Key &key, int col) const
     switch (col) {
     case 0: {
         if (key.shortKeyID()) {
-            return QString::fromUtf8(key.shortKeyID());
+            return Formatting::prettyID(key.shortKeyID());
         } else {
             return xi18n("<placeholder>unknown</placeholder>");
         }
@@ -227,7 +227,7 @@ QString ColumnStrategy::text(const GpgME::Key &key, int col) const
         if (key.protocol() == GpgME::OpenPGP) {
             return uid && *uid ? QString::fromUtf8(uid) : QString();
         } else { // CMS
-            return Kleo::DN(uid).prettyDN();
+            return DN(uid).prettyDN();
         }
     }
     default:
@@ -235,14 +235,28 @@ QString ColumnStrategy::text(const GpgME::Key &key, int col) const
     }
 }
 
+QString ColumnStrategy::accessibleText(const GpgME::Key &key, int col) const
+{
+    switch (col) {
+    case 0: {
+        if (key.shortKeyID()) {
+            return Formatting::accessibleHexID(key.shortKeyID());
+        }
+        [[fallthrough]];
+    }
+    default:
+        return {};
+    }
+}
+
 QString ColumnStrategy::toolTip(const GpgME::Key &key, int) const
 {
     const char *uid = key.userID(0).id();
     const char *fpr = key.primaryFingerprint();
     const char *issuer = key.issuerName();
     const GpgME::Subkey subkey = key.subkey(0);
-    const QString expiry = subkey.neverExpires() ? i18n("never") : time_t2string(subkey.expirationTime());
-    const QString creation = time_t2string(subkey.creationTime());
+    const QString expiry = Formatting::expirationDateString(subkey);
+    const QString creation = Formatting::creationDateString(subkey);
     QString keyStatusString;
     if (!checkKeyUsage(key, mKeyUsage, &keyStatusString)) {
         // Show the status in bold if there is a problem
@@ -253,20 +267,23 @@ QString ColumnStrategy::toolTip(const GpgME::Key &key, int) const
     if (key.protocol() == GpgME::OpenPGP) {
         html += i18n("OpenPGP key for <b>%1</b>", uid ? QString::fromUtf8(uid) : i18n("unknown"));
     } else {
-        html += i18n("S/MIME key for <b>%1</b>", uid ? Kleo::DN(uid).prettyDN() : i18n("unknown"));
+        html += i18n("S/MIME key for <b>%1</b>", uid ? DN(uid).prettyDN() : i18n("unknown"));
     }
     html += QStringLiteral("</p><table>");
 
     const auto addRow = [&html](const QString &name, const QString &value) {
         html += QStringLiteral("<tr><td align=\"right\"><b>%1: </b></td><td>%2</td></tr>").arg(name, value);
     };
-    addRow(i18nc("Key creation date", "Created"), creation);
-    addRow(i18nc("Key Expiration date", "Expiry"), expiry);
+    addRow(i18n("Valid from"), creation);
+    addRow(i18n("Valid until"), expiry);
     addRow(i18nc("Key fingerprint", "Fingerprint"), fpr ? QString::fromLatin1(fpr) : i18n("unknown"));
     if (key.protocol() != GpgME::OpenPGP) {
-        addRow(i18nc("Key issuer", "Issuer"), issuer ? Kleo::DN(issuer).prettyDN() : i18n("unknown"));
+        addRow(i18nc("Key issuer", "Issuer"), issuer ? DN(issuer).prettyDN() : i18n("unknown"));
     }
     addRow(i18nc("Key status", "Status"), keyStatusString);
+    if (DeVSCompliance::isActive()) {
+        addRow(i18nc("Compliance of key", "Compliance"), DeVSCompliance::name(key.isDeVs()));
+    }
     html += QStringLiteral("</table></qt>");
 
     return html;
@@ -299,16 +316,20 @@ QIcon ColumnStrategy::icon(const GpgME::Key &key, int col) const
         return mKeyValidPix;
     case GpgME::UserID::Marginal:
     case GpgME::UserID::Full:
-    case GpgME::UserID::Ultimate:
+    case GpgME::UserID::Ultimate: {
+        if (DeVSCompliance::isActive() && !key.isDeVs()) {
+            return mKeyValidPix;
+        }
         return mKeyGoodPix;
     }
+    }
 }
 
 }
 
 static const int sCheckSelectionDelay = 250;
 
-Kleo::KeySelectionDialog::KeySelectionDialog(QWidget *parent, Options options)
+KeySelectionDialog::KeySelectionDialog(QWidget *parent, Options options)
     : QDialog(parent)
     , mOpenPGPBackend(QGpgME::openpgp())
     , mSMIMEBackend(QGpgME::smime())
@@ -318,14 +339,14 @@ Kleo::KeySelectionDialog::KeySelectionDialog(QWidget *parent, Options options)
     setUpUI(options, QString());
 }
 
-Kleo::KeySelectionDialog::KeySelectionDialog(const QString &title,
-                                             const QString &text,
-                                             const std::vector<GpgME::Key> &selectedKeys,
-                                             unsigned int keyUsage,
-                                             bool extendedSelection,
-                                             bool rememberChoice,
-                                             QWidget *parent,
-                                             bool modal)
+KeySelectionDialog::KeySelectionDialog(const QString &title,
+                                       const QString &text,
+                                       const std::vector<GpgME::Key> &selectedKeys,
+                                       unsigned int keyUsage,
+                                       bool extendedSelection,
+                                       bool rememberChoice,
+                                       QWidget *parent,
+                                       bool modal)
     : QDialog(parent)
     , mSelectedKeys(selectedKeys)
     , mKeyUsage(keyUsage)
@@ -335,15 +356,15 @@ Kleo::KeySelectionDialog::KeySelectionDialog(const QString &title,
     init(rememberChoice, extendedSelection, text, QString());
 }
 
-Kleo::KeySelectionDialog::KeySelectionDialog(const QString &title,
-                                             const QString &text,
-                                             const QString &initialQuery,
-                                             const std::vector<GpgME::Key> &selectedKeys,
-                                             unsigned int keyUsage,
-                                             bool extendedSelection,
-                                             bool rememberChoice,
-                                             QWidget *parent,
-                                             bool modal)
+KeySelectionDialog::KeySelectionDialog(const QString &title,
+                                       const QString &text,
+                                       const QString &initialQuery,
+                                       const std::vector<GpgME::Key> &selectedKeys,
+                                       unsigned int keyUsage,
+                                       bool extendedSelection,
+                                       bool rememberChoice,
+                                       QWidget *parent,
+                                       bool modal)
     : QDialog(parent)
     , mSelectedKeys(selectedKeys)
     , mKeyUsage(keyUsage)
@@ -355,14 +376,14 @@ Kleo::KeySelectionDialog::KeySelectionDialog(const QString &title,
     init(rememberChoice, extendedSelection, text, initialQuery);
 }
 
-Kleo::KeySelectionDialog::KeySelectionDialog(const QString &title,
-                                             const QString &text,
-                                             const QString &initialQuery,
-                                             unsigned int keyUsage,
-                                             bool extendedSelection,
-                                             bool rememberChoice,
-                                             QWidget *parent,
-                                             bool modal)
+KeySelectionDialog::KeySelectionDialog(const QString &title,
+                                       const QString &text,
+                                       const QString &initialQuery,
+                                       unsigned int keyUsage,
+                                       bool extendedSelection,
+                                       bool rememberChoice,
+                                       QWidget *parent,
+                                       bool modal)
     : QDialog(parent)
     , mKeyUsage(keyUsage)
     , mSearchText(initialQuery)
@@ -373,7 +394,7 @@ Kleo::KeySelectionDialog::KeySelectionDialog(const QString &title,
     init(rememberChoice, extendedSelection, text, initialQuery);
 }
 
-void Kleo::KeySelectionDialog::setUpUI(Options options, const QString &initialQuery)
+void KeySelectionDialog::setUpUI(Options options, const QString &initialQuery)
 {
     auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
@@ -453,7 +474,7 @@ void Kleo::KeySelectionDialog::setUpUI(Options options, const QString &initialQu
     });
     connectSignals();
 
-    connect(mKeyListView, &Kleo::KeyListView::doubleClicked, this, &KeySelectionDialog::slotTryOk);
+    connect(mKeyListView, &KeyListView::doubleClicked, this, &KeySelectionDialog::slotTryOk);
     connect(mKeyListView, &KeyListView::contextMenu, this, &KeySelectionDialog::slotRMB);
 
     if (options & RereadKeys) {
@@ -485,7 +506,7 @@ void Kleo::KeySelectionDialog::setUpUI(Options options, const QString &initialQu
     }
 }
 
-void Kleo::KeySelectionDialog::init(bool rememberChoice, bool extendedSelection, const QString &text, const QString &initialQuery)
+void KeySelectionDialog::init(bool rememberChoice, bool extendedSelection, const QString &text, const QString &initialQuery)
 {
     Options options = {RereadKeys, ExternalCertificateManager};
     options.setFlag(ExtendedSelection, extendedSelection);
@@ -504,7 +525,7 @@ void Kleo::KeySelectionDialog::init(bool rememberChoice, bool extendedSelection,
     slotRereadKeys();
 }
 
-Kleo::KeySelectionDialog::~KeySelectionDialog()
+KeySelectionDialog::~KeySelectionDialog()
 {
     disconnectSignals();
     KConfigGroup dialogConfig(KSharedConfig::openStateConfig(), "Key Selection Dialog");
@@ -513,20 +534,20 @@ Kleo::KeySelectionDialog::~KeySelectionDialog()
     dialogConfig.sync();
 }
 
-void Kleo::KeySelectionDialog::setText(const QString &text)
+void KeySelectionDialog::setText(const QString &text)
 {
     mTextLabel->setText(text);
     mTextLabel->setVisible(!text.isEmpty());
 }
 
-void Kleo::KeySelectionDialog::setKeys(const std::vector<GpgME::Key> &keys)
+void KeySelectionDialog::setKeys(const std::vector<GpgME::Key> &keys)
 {
     for (const GpgME::Key &key : keys) {
         mKeyListView->slotAddKey(key);
     }
 }
 
-void Kleo::KeySelectionDialog::connectSignals()
+void KeySelectionDialog::connectSignals()
 {
     if (mKeyListView->isMultiSelection()) {
         connect(mKeyListView, &QTreeWidget::itemSelectionChanged, this, &KeySelectionDialog::slotSelectionChanged);
@@ -538,7 +559,7 @@ void Kleo::KeySelectionDialog::connectSignals()
     }
 }
 
-void Kleo::KeySelectionDialog::disconnectSignals()
+void KeySelectionDialog::disconnectSignals()
 {
     if (mKeyListView->isMultiSelection()) {
         disconnect(mKeyListView, &QTreeWidget::itemSelectionChanged, this, &KeySelectionDialog::slotSelectionChanged);
@@ -550,7 +571,7 @@ void Kleo::KeySelectionDialog::disconnectSignals()
     }
 }
 
-const GpgME::Key &Kleo::KeySelectionDialog::selectedKey() const
+const GpgME::Key &KeySelectionDialog::selectedKey() const
 {
     static const GpgME::Key null = GpgME::Key::null;
     if (mKeyListView->isMultiSelection() || !mKeyListView->selectedItem()) {
@@ -559,12 +580,12 @@ const GpgME::Key &Kleo::KeySelectionDialog::selectedKey() const
     return mKeyListView->selectedItem()->key();
 }
 
-QString Kleo::KeySelectionDialog::fingerprint() const
+QString KeySelectionDialog::fingerprint() const
 {
     return QLatin1String(selectedKey().primaryFingerprint());
 }
 
-QStringList Kleo::KeySelectionDialog::fingerprints() const
+QStringList KeySelectionDialog::fingerprints() const
 {
     QStringList result;
     for (auto it = mSelectedKeys.begin(); it != mSelectedKeys.end(); ++it) {
@@ -575,7 +596,7 @@ QStringList Kleo::KeySelectionDialog::fingerprints() const
     return result;
 }
 
-QStringList Kleo::KeySelectionDialog::pgpKeyFingerprints() const
+QStringList KeySelectionDialog::pgpKeyFingerprints() const
 {
     QStringList result;
     for (auto it = mSelectedKeys.begin(); it != mSelectedKeys.end(); ++it) {
@@ -588,7 +609,7 @@ QStringList Kleo::KeySelectionDialog::pgpKeyFingerprints() const
     return result;
 }
 
-QStringList Kleo::KeySelectionDialog::smimeFingerprints() const
+QStringList KeySelectionDialog::smimeFingerprints() const
 {
     QStringList result;
     for (auto it = mSelectedKeys.begin(); it != mSelectedKeys.end(); ++it) {
@@ -601,7 +622,7 @@ QStringList Kleo::KeySelectionDialog::smimeFingerprints() const
     return result;
 }
 
-void Kleo::KeySelectionDialog::slotRereadKeys()
+void KeySelectionDialog::slotRereadKeys()
 {
     mKeyListView->clear();
     mListJobCount = 0;
@@ -629,7 +650,7 @@ void Kleo::KeySelectionDialog::slotRereadKeys()
     }
 }
 
-void Kleo::KeySelectionDialog::slotStartCertificateManager(const QString &query)
+void KeySelectionDialog::slotStartCertificateManager(const QString &query)
 {
     QStringList args;
 
@@ -674,7 +695,7 @@ struct ExtractFingerprint {
 };
 }
 
-void Kleo::KeySelectionDialog::startKeyListJobForBackend(const QGpgME::Protocol *backend, const std::vector<GpgME::Key> &keys, bool validate)
+void KeySelectionDialog::startKeyListJobForBackend(const QGpgME::Protocol *backend, const std::vector<GpgME::Key> &keys, bool validate)
 {
     Q_ASSERT(backend);
     QGpgME::KeyListJob *job = backend->keyListJob(false, false, validate); // local, w/o sigs, validation as given
@@ -704,20 +725,20 @@ void Kleo::KeySelectionDialog::startKeyListJobForBackend(const QGpgME::Protocol
     ++mListJobCount;
 }
 
-static void selectKeys(Kleo::KeyListView *klv, const std::vector<GpgME::Key> &selectedKeys)
+static void selectKeys(KeyListView *klv, const std::vector<GpgME::Key> &selectedKeys)
 {
     klv->clearSelection();
     if (selectedKeys.empty()) {
         return;
     }
     for (auto it = selectedKeys.begin(); it != selectedKeys.end(); ++it) {
-        if (Kleo::KeyListViewItem *item = klv->itemByFingerprint(it->primaryFingerprint())) {
+        if (KeyListViewItem *item = klv->itemByFingerprint(it->primaryFingerprint())) {
             item->setSelected(true);
         }
     }
 }
 
-void Kleo::KeySelectionDialog::slotKeyListResult(const GpgME::KeyListResult &res)
+void KeySelectionDialog::slotKeyListResult(const GpgME::KeyListResult &res)
 {
     if (res.error()) {
         showKeyListError(this, res.error());
@@ -758,7 +779,7 @@ void Kleo::KeySelectionDialog::slotKeyListResult(const GpgME::KeyListResult &res
     mSavedOffsetY = 0;
 }
 
-void Kleo::KeySelectionDialog::slotSelectionChanged()
+void KeySelectionDialog::slotSelectionChanged()
 {
     qCDebug(KLEO_UI_LOG) << "KeySelectionDialog::slotSelectionChanged()";
 
@@ -778,7 +799,7 @@ struct AlreadyChecked {
 };
 }
 
-void Kleo::KeySelectionDialog::slotCheckSelection(KeyListViewItem *item)
+void KeySelectionDialog::slotCheckSelection(KeyListViewItem *item)
 {
     qCDebug(KLEO_UI_LOG) << "KeySelectionDialog::slotCheckSelection()";
 
@@ -809,7 +830,7 @@ void Kleo::KeySelectionDialog::slotCheckSelection(KeyListViewItem *item)
     startValidatingKeyListing();
 }
 
-void Kleo::KeySelectionDialog::startValidatingKeyListing()
+void KeySelectionDialog::startValidatingKeyListing()
 {
     if (mKeysToCheck.empty()) {
         return;
@@ -844,12 +865,12 @@ void Kleo::KeySelectionDialog::startValidatingKeyListing()
     Q_ASSERT(mListJobCount > 0);
 }
 
-bool Kleo::KeySelectionDialog::rememberSelection() const
+bool KeySelectionDialog::rememberSelection() const
 {
     return mRememberCB && mRememberCB->isChecked();
 }
 
-void Kleo::KeySelectionDialog::slotRMB(Kleo::KeyListViewItem *item, const QPoint &p)
+void KeySelectionDialog::slotRMB(KeyListViewItem *item, const QPoint &p)
 {
     if (!item) {
         return;
@@ -862,7 +883,7 @@ void Kleo::KeySelectionDialog::slotRMB(Kleo::KeyListViewItem *item, const QPoint
     menu.exec(p);
 }
 
-void Kleo::KeySelectionDialog::slotRecheckKey()
+void KeySelectionDialog::slotRecheckKey()
 {
     if (!mCurrentContextMenuItem || mCurrentContextMenuItem->key().isNull()) {
         return;
@@ -872,14 +893,14 @@ void Kleo::KeySelectionDialog::slotRecheckKey()
     mKeysToCheck.push_back(mCurrentContextMenuItem->key());
 }
 
-void Kleo::KeySelectionDialog::slotTryOk()
+void KeySelectionDialog::slotTryOk()
 {
     if (!mSelectedKeys.empty() && checkKeyUsage(mSelectedKeys, mKeyUsage)) {
         slotOk();
     }
 }
 
-void Kleo::KeySelectionDialog::slotOk()
+void KeySelectionDialog::slotOk()
 {
     if (mCheckSelectionTimer->isActive()) {
         slotCheckSelection();
@@ -894,26 +915,26 @@ void Kleo::KeySelectionDialog::slotOk()
     accept();
 }
 
-void Kleo::KeySelectionDialog::slotCancel()
+void KeySelectionDialog::slotCancel()
 {
     mCheckSelectionTimer->stop();
     mStartSearchTimer->stop();
     reject();
 }
 
-void Kleo::KeySelectionDialog::slotSearch(const QString &text)
+void KeySelectionDialog::slotSearch(const QString &text)
 {
     mSearchText = text.trimmed().toUpper();
     slotSearch();
 }
 
-void Kleo::KeySelectionDialog::slotSearch()
+void KeySelectionDialog::slotSearch()
 {
     mStartSearchTimer->setSingleShot(true);
     mStartSearchTimer->start(sCheckSelectionDelay);
 }
 
-void Kleo::KeySelectionDialog::slotFilter()
+void KeySelectionDialog::slotFilter()
 {
     if (mSearchText.isEmpty()) {
         showAllItems();
@@ -938,7 +959,7 @@ void Kleo::KeySelectionDialog::slotFilter()
     }
 }
 
-void Kleo::KeySelectionDialog::filterByKeyID(const QString &keyID)
+void KeySelectionDialog::filterByKeyID(const QString &keyID)
 {
     Q_ASSERT(keyID.length() <= 8);
     Q_ASSERT(!keyID.isEmpty()); // regexp in slotFilter should prevent these
@@ -951,7 +972,7 @@ void Kleo::KeySelectionDialog::filterByKeyID(const QString &keyID)
     }
 }
 
-static bool anyUIDMatches(const Kleo::KeyListViewItem *item, QRegExp &rx)
+static bool anyUIDMatches(const KeyListViewItem *item, QRegExp &rx)
 {
     if (!item) {
         return false;
@@ -966,7 +987,7 @@ static bool anyUIDMatches(const Kleo::KeyListViewItem *item, QRegExp &rx)
     return false;
 }
 
-void Kleo::KeySelectionDialog::filterByKeyIDOrUID(const QString &str)
+void KeySelectionDialog::filterByKeyIDOrUID(const QString &str)
 {
     Q_ASSERT(!str.isEmpty());
 
@@ -978,7 +999,7 @@ void Kleo::KeySelectionDialog::filterByKeyIDOrUID(const QString &str)
     }
 }
 
-void Kleo::KeySelectionDialog::filterByUID(const QString &str)
+void KeySelectionDialog::filterByUID(const QString &str)
 {
     Q_ASSERT(!str.isEmpty());
 
@@ -990,7 +1011,7 @@ void Kleo::KeySelectionDialog::filterByUID(const QString &str)
     }
 }
 
-void Kleo::KeySelectionDialog::showAllItems()
+void KeySelectionDialog::showAllItems()
 {
     for (KeyListViewItem *item = mKeyListView->firstChild(); item; item = item->nextSibling()) {
         item->setHidden(false);
